/*
 * This file is part of the Nepomuk KDE project.
 *
 * This library is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * See the file "COPYING" for the exact licensing terms.
 */

/*
 * This file has been generated by the Nepomuk Resource class generator.
 * DO NOT EDIT THIS FILE.
 * ANY CHANGES WILL BE LOST.
 */

#ifndef _DATAOBJECT_H_
#define _DATAOBJECT_H_

class QDateTime;
class QDate;
class QTime;

namespace NepomukFast {
        class Media;
        class InformationElement;
        class DataSource;
        class DataContainer;
        class Contact;
        class Resource;
        class OrganizationContact;

}

#include "resource.h"
#include <nepomuk/nepomuk_export.h>

namespace NepomukFast {

/**
 * A unit of data that is created, annotated and processed on the 
 * user desktop. It represents a native structure the user works 
 * with. The usage of the term 'native' is important. It means that 
 * a DataObject can be directly mapped to a data structure maintained 
 * by a native application. This may be a file, a set of files or a 
 * part of a file. The granularity depends on the user. This class 
 * is not intended to be instantiated by itself. Use more specific 
 * subclasses. 
 */
    class NEPOMUK_EXPORT DataObject : public NepomukFast::Resource
    {
    public:
        /**
         * Create a new empty and invalid DataObject instance
         */
        DataObject( const QUrl &uri = QUrl(), const QUrl &graphUri = QUrl() );

                    /**
             * Set property 'created'. Date of creation of the DataObject. 
             * Note that this date refers to the creation of the DataObject 
             * itself (i.e. the physical representation). Compare with nie:contentCreated. 
             */
            void setCreateds( const QList<QDateTime>& value );

            /**
             * Add a value to property 'created'. Date of creation of the DataObject. 
             * Note that this date refers to the creation of the DataObject 
             * itself (i.e. the physical representation). Compare with nie:contentCreated. 
             */
            void addCreated( const QDateTime& value );

            /**
             * \return The URI of the property 'created'. 
             */
            static QUrl createdUri();

            /**
             * Set property 'interpretedAs'. Links the DataObject with the 
             * InformationElement it is interpreted as. 
             */
            void setInterpretedAses( const QList<InformationElement>& value );

            /**
             * Add a value to property 'interpretedAs'. Links the DataObject 
             * with the InformationElement it is interpreted as. 
             */
            void addInterpretedAs( const InformationElement& value );

            /**
             * \return The URI of the property 'interpretedAs'. 
             */
            static QUrl interpretedAsUri();

            /**
             * Set property 'isPartOf'. Generic property used to express 
             * containment relationships between DataObjects. NIE extensions 
             * are encouraged to provide more specific subproperties of this 
             * one. It is advisable for actual instances of DataObjects to 
             * use those specific subproperties. Note to the developers: 
             * Please be aware of the distinction between containment relation 
             * and provenance. The isPartOf relation models physical containment, 
             * a nie:DataObject (e.g. an nfo:Attachment) is a 'physical' 
             * part of an nie:InformationElement (a nmo:Message). Also, 
             * please note the difference between physical containment (isPartOf) 
             * and logical containment (isLogicalPartOf) the former has 
             * more strict meaning. They may occur independently of each other. 
             */
            void setIsPartOfs( const QList<InformationElement>& value );

            /**
             * Add a value to property 'isPartOf'. Generic property used to 
             * express containment relationships between DataObjects. 
             * NIE extensions are encouraged to provide more specific subproperties 
             * of this one. It is advisable for actual instances of DataObjects 
             * to use those specific subproperties. Note to the developers: 
             * Please be aware of the distinction between containment relation 
             * and provenance. The isPartOf relation models physical containment, 
             * a nie:DataObject (e.g. an nfo:Attachment) is a 'physical' 
             * part of an nie:InformationElement (a nmo:Message). Also, 
             * please note the difference between physical containment (isPartOf) 
             * and logical containment (isLogicalPartOf) the former has 
             * more strict meaning. They may occur independently of each other. 
             */
            void addIsPartOf( const InformationElement& value );

            /**
             * \return The URI of the property 'isPartOf'. 
             */
            static QUrl isPartOfUri();

            /**
             * Set property 'lastRefreshed'. Date when information about 
             * this data object was retrieved (for the first time) or last refreshed 
             * from the data source. This property is important for metadata 
             * extraction applications that don't receive any notifications 
             * of changes in the data source and have to poll it regularly. This 
             * may lead to information becoming out of date. In these cases 
             * this property may be used to determine the age of data, which 
             * is an important element of it's dependability. 
             */
            void setLastRefreshed( const QDateTime& value );

            /**
             * \return The URI of the property 'lastRefreshed'. 
             */
            static QUrl lastRefreshedUri();

            /**
             * Set property 'dataSource'. Marks the provenance of a DataObject, 
             * what source does a data object come from. 
             */
            void setDataSources( const QList<DataSource>& value );

            /**
             * Add a value to property 'dataSource'. Marks the provenance 
             * of a DataObject, what source does a data object come from. 
             */
            void addDataSource( const DataSource& value );

            /**
             * \return The URI of the property 'dataSource'. 
             */
            static QUrl dataSourceUri();

            /**
             * Set property 'byteSize'. The overall size of the data object 
             * in bytes. That means the WHOLE data object and ONLY the data object, 
             * not of the content that is of interest to the user. For cases where 
             * the content size is different (e.g. in compressed files the 
             * content is larger, in messages the content excludes headings 
             * and is smaller) use more specific properties, not necessarily 
             * subproperties of this one. 
             */
            void setByteSize( const qint64& value );

            /**
             * \return The URI of the property 'byteSize'. 
             */
            static QUrl byteSizeUri();

            /**
             * Set property 'belongsToContainer'. Models the containment 
             * relations between Files and Folders (or CompressedFiles). 
             */
            void setBelongsToContainers( const QList<DataContainer>& value );

            /**
             * Add a value to property 'belongsToContainer'. Models the containment 
             * relations between Files and Folders (or CompressedFiles). 
             */
            void addBelongsToContainer( const DataContainer& value );

            /**
             * \return The URI of the property 'belongsToContainer'. 
             */
            static QUrl belongsToContainerUri();



    protected:
        DataObject( const QUrl& uri, const QUrl& graphUri, const QUrl& type );
    };
}

#endif
